@@ -32,8 +32,10 @@ Example Usage:
 .. versionadded:: 0.6.0
 '''
 from __future__ import absolute_import
+from itertools import chain
+
 from textblob.packages import nltk
-from textblob.tokenizers import WordTokenizer
+from textblob.tokenizers import word_tokenize
 from textblob.compat import basestring
 import textblob.formats as formats
 from textblob.utils import strip_punc
@@ -48,14 +50,14 @@ def _get_words_from_dataset(dataset):
     :param dataset: A list of tuples of the form ``(words, label)`` where
         ``words`` is either a string of a list of tokens.
     '''
-    tokenizer = WordTokenizer()
-    all_words = []
-    for words, classification in dataset:
-        # Words may either be a string or an iterable
+    # Words may be either a string or a list of tokens. Return an iterator
+    # of tokens accordingly
+    def tokenize(words):
         if isinstance(words, basestring):
-            all_words.extend(tokenizer.itokenize(words, include_punc=False))
+            return word_tokenize(words, include_punc=False)
         else:
-            all_words.extend(words)
+            return (w for w in words)
+    all_words = chain.from_iterable(tokenize(words) for words, _ in dataset)
     return set(all_words)
 
 
@@ -67,11 +69,10 @@ def basic_extractor(document, train_set):
     :param train_set: Training data set, a list of tuples of the form
         ``(words, label)``.
     '''
-    tokenizer = WordTokenizer()
     word_features = _get_words_from_dataset(train_set)
     if isinstance(document, basestring):
         tokens = set((strip_punc(w, all=False)
-                    for w in tokenizer.itokenize(document, include_punc=False)))
+                    for w in word_tokenize(document, include_punc=False)))
     else:
         tokens = set(strip_punc(w, all=False) for w in document)
     features = dict(((u'contains({0})'.format(word), (word in tokens))
@@ -83,10 +84,9 @@ def contains_extractor(document):
     '''A basic document feature extractor that returns a dict of words that
     the document contains.
     '''
-    tokenizer = WordTokenizer()
     if isinstance(document, basestring):
         tokens = set([strip_punc(w, all=False)
-                    for w in tokenizer.itokenize(document, include_punc=False)])
+                    for w in word_tokenize(document, include_punc=False)])
     else:
         tokens = set((strip_punc(w, all=False) for w in document))
     features = dict((u'contains({0})'.format(w), True) for w in tokens)
@@ -103,9 +103,9 @@ class BaseClassifier(object):
     :param train_set: The training set, either a list of tuples of the form
         ``(text, classification)`` or a filename. ``text`` may be either
         a string or an iterable.
-    :param feature_extractor: A feature extractor function that takes one or
+    :param function feature_extractor: A feature extractor function that takes one or
         two arguments: ``document`` and ``train_set``.
-    :param format: If ``train_set`` is a filename, the file format, e.g.
+    :param str format: If ``train_set`` is a filename, the file format, e.g.
         ``"csv"`` or ``"json"``. If ``None``, will attempt to detect the
         file format.
 
@@ -155,6 +155,7 @@ class BaseClassifier(object):
 
         :rtype: dictionary of features
         '''
+        # Feature extractor may take 1 or two arguments
         try:
             return self.feature_extractor(text, self.train_set)
         except (TypeError, AttributeError):
@@ -175,7 +176,8 @@ class NLTKClassifier(BaseClassifier):
 
     """
 
-    nltk_class = None  # This must be a class within nltk.classify
+    #: The NLTK class to be wrapped. Must be a class within nltk.classify
+    nltk_class = None
 
     def __init__(self, train_set,
                  feature_extractor=basic_extractor, format=None):
@@ -222,7 +224,7 @@ class NLTKClassifier(BaseClassifier):
     def classify(self, text):
         '''Classifies the text.
 
-        :param text: A string of text.
+        :param str text: A string of text.
         '''
         text_features = self.extract_features(text)
         return self.classifier.classify(text_features)
@@ -415,6 +417,7 @@ class PositiveNaiveBayesClassifier(NLTKClassifier):
                         .format(cls=class_name, n_pos=len(self.positive_set),
                                 n_unlabeled=len(self.unlabeled_set))
 
+    # Override
     def train(self, *args, **kwargs):
         '''Train the classifier with a labeled and unlabeled feature sets and return
         the classifier. Takes the same arguments as the wrapped NLTK class.
@@ -452,3 +455,27 @@ class PositiveNaiveBayesClassifier(NLTKClassifier):
                                                 self.positive_prob_prior,
                                                 *args, **kwargs)
         return True
+
+
+class MaxEntClassifier(NLTKClassifier):
+    __doc__ = nltk.classify.maxent.MaxentClassifier.__doc__
+    nltk_class = nltk.classify.maxent.MaxentClassifier
+
+    def prob_classify(self, text):
+        '''Return the label probability distribution for classifying a string
+        of text.
+
+        Example:
+        ::
+
+            >>> classifier = MaxEntClassifier(train_data)
+            >>> prob_dist = classifier.prob_classify("I feel happy this morning.")
+            >>> prob_dist.max()
+            'positive'
+            >>> prob_dist.prob("positive")
+            0.7
+
+        :rtype: nltk.probability.DictionaryProbDist
+        '''
+        feats = self.extract_features(text)
+        return self.classifier.prob_classify(feats)
